@@ -126,6 +126,6 @@ class TwelveData():
 
         data = dataReal.sort_index(ascending=True)
         data = data[["open","high","low","close","percent_b","slow_k","slow_d","apo","supertrend","trange","ultosc"]]
-        obs  = obs.reshape(1320,)
+        obs  = data.reshape(165,)
 
         return obs
\ No newline at end of file
